@@ -6,6 +6,8 @@ from typing import Any, Dict, List, Optional, Union
 from pathlib import Path
 import logging
 
+from .output import get_tree_name
+
 log = logging.getLogger(__name__)
 
 class ServiceXFrontend:
@@ -37,17 +39,14 @@ class ServiceXFrontend:
 
         if 'uproot' in self._backend:
             transformer_image = "sslhep/servicex_func_adl_uproot_transformer:develop"
-            # transformer_image = "kyungeonchoi/servicex_func_adl_uproot_transformer:0.7"
         elif 'xaod' in self._backend:
             transformer_image = "sslhep/servicex_func_adl_xaod_transformer:develop"
         
         nest_asyncio.apply()
  
-        # async def bound_get_data(sem, sx_ds, query):
-        async def bound_get_data(sem, sx_ds, query, sample):
+        async def bound_get_data(sem, sx_ds, query, title):
             async with sem:
-                # return await sx_ds.get_data_parquet_async(query)
-                return await sx_ds.get_data_parquet_async(query, sample) # When fix in ServiceX Frontend
+                return await sx_ds.get_data_parquet_async(query, title)
 
         async def _get_my_data():
             sem = asyncio.Semaphore(50) # Limit maximum concurrent ServiceX requests
@@ -61,10 +60,13 @@ class ServiceXFrontend:
                                             session_generator=session, \
                                             ignore_cache=ignoreCache)
                     query = request['query']
-                    sample = request['Sample']
-
-                    # task = asyncio.ensure_future(bound_get_data(sem, sx_ds, query))
-                    task = asyncio.ensure_future(bound_get_data(sem, sx_ds, query, sample))
+                    
+                    if 'uproot' in self._backend:
+                        title = request['Sample'] + ' - ' + get_tree_name(query)
+                    else:
+                        title = request['Sample']
+                        
+                    task = asyncio.ensure_future(bound_get_data(sem, sx_ds, query, title))
                     tasks.append(task)
                 return await asyncio.gather(*tasks)
 
